<?php
declare(strict_types = 1);

return [
    'headers' => [
        'server' => [
            'nginx'
        ],
        'date' => [
            'Sun, 04 Apr 2021 15:20:41 GMT'
        ],
        'content-type' => [
            'application/json; charset=UTF-8'
        ],
        'vary' => [
            'Accept-Encoding'
        ],
        'x-hacker' => [
            'If you\'re reading this, you should visit automattic.com/jobs and apply to join the fun, mention this header.'
        ],
        'host-header' => [
            'WordPress.com'
        ],
        'content-encoding' => [
            'gzip'
        ],
        'x-ac' => [
            '2.mad _dca'
        ],
        'strict-transport-security' => [
            'max-age=15552000'
        ],
        'Content-Location' => [
            'https://public-api.wordpress.com/oembed/?format=json&url=https%3A%2F%2Fwordpress.tv%2F2013%2F09%2F06%2Fdave-ross-optimize-image-files-like-a-pro%2F&for=wpcom-auto-discovery'
        ],
        'X-Request-Time' => [
            '0.277 ms'
        ]
    ],
    'statusCode' => 200,
    'reasonPhrase' => 'OK',
    'body' => '{"version":"1.0","provider_name":"WordPress.tv","provider_url":"http:\\/\\/wordpress.tv","author_name":"WordPress.tv","author_url":"https:\\/\\/wordpress.tv\\/author\\/anonvideoupload\\/","title":"Dave Ross: Optimize Image Files Like a&nbsp;Pro","type":"link","html":"Images, even small ones, can be the biggest files that make up your site. Learn the tools, plugins, and theming techniques you\\u2019ll want to start using to shrink your page load times and save your mobile users a few bucks without sacrificing image quality.\\r\\n\\r\\n<a href=\\"http:\\/\\/slides.davidmichaelross.com\\/image_optimization\\/#\\/\\" target=\\"_blank\\">Presentation Slides &raquo;<\\/a>"}'
];
