<?php
declare(strict_types = 1);

return [
    'headers' => [
        'date' => [
            'Sun, 04 Apr 2021 15:20:32 GMT'
        ],
        'server' => [
            'mw1347.eqiad.wmnet'
        ],
        'x-content-type-options' => [
            'nosniff'
        ],
        'p3p' => [
            'CP="See https://en.wikipedia.org/wiki/Special:CentralAutoLogin/P3P for more info."'
        ],
        'x-frame-options' => [
            'SAMEORIGIN'
        ],
        'content-disposition' => [
            'inline; filename=api-result.json'
        ],
        'vary' => [
            'Accept-Encoding,Treat-as-Untrusted,X-Forwarded-Proto,Cookie,Authorization'
        ],
        'cache-control' => [
            'private, must-revalidate, max-age=0'
        ],
        'x-request-id' => [
            '567daf4c-3d28-4f48-804a-1ce4f8f3cd8e'
        ],
        'content-type' => [
            'application/json; charset=utf-8'
        ],
        'content-encoding' => [
            'gzip'
        ],
        'age' => [
            '11'
        ],
        'x-cache' => [
            'cp3056 miss, cp3062 pass'
        ],
        'x-cache-status' => [
            'pass'
        ],
        'server-timing' => [
            'cache;desc="pass", host;desc="cp3062"'
        ],
        'strict-transport-security' => [
            'max-age=106384710; includeSubDomains; preload'
        ],
        'report-to' => [
            '{ "group": "wm_nel", "max_age": 86400, "endpoints": [{ "url": "https://intake-logging.wikimedia.org/v1/events?stream=w3c.reportingapi.network_error&schema_uri=/w3c/reportingapi/network_error/1.0.0" }] }'
        ],
        'nel' => [
            '{ "report_to": "wm_nel", "max_age": 86400, "failure_fraction": 0.05, "success_fraction": 0.0}'
        ],
        'x-client-ip' => [
            '89.6.157.99'
        ],
        'accept-ranges' => [
            'bytes'
        ],
        'Content-Location' => [
            'https://en.wikipedia.org/w/api.php?action=query&format=json&continue=&titles=Albert_Einstein&prop=extracts&exchars=1000'
        ],
        'X-Request-Time' => [
            '6.065 ms'
        ]
    ],
    'statusCode' => 200,
    'reasonPhrase' => 'OK',
    'body' => '{"batchcomplete":"","warnings":{"extracts":{"*":"HTML may be malformed and/or unbalanced and may omit inline images. Use at your own risk. Known problems are listed at https://www.mediawiki.org/wiki/Special:MyLanguage/Extension:TextExtracts#Caveats."}},"query":{"normalized":[{"from":"Albert_Einstein","to":"Albert Einstein"}],"pages":{"736":{"pageid":736,"ns":0,"title":"Albert Einstein","extract":"<p class=\\"mw-empty-elt\\">\\n\\n</p>\\n\\n<p class=\\"mw-empty-elt\\">\\n</p>\\n<p><b>Albert Einstein</b> (<span></span> <i title=\\"English pronunciation respelling\\"><span>EYEN</span>-styne</i>; <small>German: </small><span title=\\"Representation in the International Phonetic Alphabet (IPA)\\">[\\u02c8alb\\u025b\\u0281t \\u02c8\\u0294a\\u026an\\u0283ta\\u026an]</span> <span>(<span><span><span></span>listen</span></span>)</span>; 14 March 1879&#160;\\u2013 18 April 1955) was a German-born theoretical physicist, widely acknowledged to be one of the greatest physicists of all time. Einstein is known widely for developing the theory of relativity, but he also made important contributions to the development of the theory of quantum mechanics. Relativity and quantum mechanics are together the two pillars of modern physics.  His mass\\u2013energy equivalence formula <span><i>E</i> = <i>mc</i><sup>2</sup></span>, which arises from relativity theory, has been dubbed \\"the world\'s most famous equation\\". His work is also known for its influence on the philosophy of science. He received</p>..."}}}}'
];
